@@ -25,22 +25,33 @@ def motioncli() -> None:
 )
 def visualize(filename: str, output: str) -> None:
     """Visualize a component."""
+    red_x = "\u274C"  # Unicode code point for red "X" emoji
     if "::" not in filename:
-        click.echo("Component must be in the format `filename::componentinstance`.")
+        click.echo(
+            f"{red_x} Component must be in the format "
+            + "`filename::componentinstance`."
+        )
         return
 
     # Remove the file extension if present
     module = filename.replace(".py", "")
 
-    module, instance = module.split("::")
-    if not module or not instance:
-        click.echo("Component must be in the format `module::componentinstance`.")
+    first, instance = module.split("::")
+    if not first or not instance:
+        click.echo(
+            f"{red_x} Component must be in the format "
+            + "`filename::componentinstance`."
+        )
         return
 
-    module = importlib.import_module(module)  # type: ignore
+    module = importlib.import_module(first)  # type: ignore
 
     # Get the class instance
-    class_instance = getattr(module, instance)
+    try:
+        class_instance = getattr(module, instance)
+    except AttributeError as e:
+        click.echo(f"{red_x} {e}")
+        return
 
     # Get the graph
     graph = class_instance.get_graph()
@@ -48,7 +59,8 @@ def visualize(filename: str, output: str) -> None:
     # Dump the graph to a file with the date
     ts = datetime.now().strftime("%Y-%m-%d-%H-%M-%S")
     out_filename = f"{ts}_{instance}_{output}"
+    checkmark = "\u2705"  # Unicode code point for checkmark emoji
 
-    with open(output, "w") as f:
+    with open(out_filename, "w") as f:
         json.dump(graph, f, indent=4)
-        click.echo(f"Graph dumped to {out_filename}.")
+        click.echo(f"{checkmark} Graph dumped to {out_filename}.")
